Module cli

Module cli 

CLI Arg Parsing library

Structs

Opts
The struct for Clap CLI arguments

Functions

parse_cli_args
Parse CLI Arguments turns a Clap Opts struct, seen above Into a library Struct for use within the program The library struct can be found in the config folder.
read_and_parse_file
When the CLI is called with -f to open a file this function opens it