Function read_and_parse_file

pub fn read_and_parse_file(file_path: String) -> String
When the CLI is called with -f to open a file this function opens it

Panics

This can panic when opening a file which does not exist!