Module cli_pretty_printing

Module cli_pretty_printing 

The CLI Pretty Printing module contains the functions that print the results

Functions

countdown_until_program_ends
Every second the timer ticks once If the timer hits our countdown, we exit the program. This function prints the countdown to let the user know the program is still running.
decoded_how_many_times
The output function is used to print the output of the program.
failed_to_decode
When Ares has failed to decode something, print this message
human_checker_check
Whenever the human checker checks for text, this function is run. The human checker checks to see if API mdoe is runnign inside of it rather than doing it here at the printing level
panic_failure_both_input_and_fail_provided
The user has provided both textual input and file input
panic_failure_no_input_provided
The user has not provided any input.
program_exiting_successful_decoding
The output function is used to print the output of the program. If the API mode is on, it will not print.
return_early_because_input_text_is_plaintext
The input given to Ares is already plaintext So we do not need to do anything