pub fn program_exiting_successful_decoding(result: DecoderResult)Expand description
The output function is used to print the output of the program. If the API mode is on, it will not print.
pub fn program_exiting_successful_decoding(result: DecoderResult)The output function is used to print the output of the program. If the API mode is on, it will not print.