pub struct Decoder<Type> {
pub name: &'static str,
pub description: &'static str,
pub link: &'static str,
pub tags: Vec<&'static str>,
pub popularity: f32,
pub phantom: PhantomData<Type>,
}Expand description
! The Interface defines what the struct for each decoder looks like
Fields
name: &'static strThe English name of the decoder.
description: &'static strA description, you can take the first line from Wikipedia Sometimes our decoders do not exist on Wikipedia so we write our own.
link: &'static strWikipedia Link
The tags it has. See other decoders. Think of it as a “category” This is used to filter decoders. For example, if you want to filter decoders that are “base64” you would use the tag “base64” or “base”. You can also add tags like “online” to filter decoders that are online.
popularity: f32We get popularity by eye-balling it or using the API’s data
phantom: PhantomData<Type>we don’t use the Type, so we use PhantomData to mark it!