pub struct AresConfigManager { /* private fields */ }Expand description
Thread-safe configuration manager with hot reloading support
Implementations
Sourceimpl AresConfigManager
impl AresConfigManager
Sourcepub fn new<P: AsRef<Path>>(path: P) -> Result<Self, ConfigError>
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, ConfigError>
Create a new configuration manager and load the initial config
Panics
Panics if ares.toml doesn’t exist or is invalid.
Sourcepub fn config(&self) -> Arc<AresConfig>
pub fn config(&self) -> Arc<AresConfig>
Get the current configuration (lockless read)
Sourcepub fn reload(&self) -> Result<(), ConfigError>
pub fn reload(&self) -> Result<(), ConfigError>
Manually reload the configuration from disk
Sourcepub fn start_watching(&mut self) -> Result<(), ConfigError>
pub fn start_watching(&mut self) -> Result<(), ConfigError>
Start watching for configuration file changes
Sourcepub fn stop_watching(&self)
pub fn stop_watching(&self)
Stop watching for configuration changes
Sourceimpl AresConfigManager
impl AresConfigManager
Sourcepub fn from_config(config: AresConfig) -> Self
pub fn from_config(config: AresConfig) -> Self
Create a config manager directly from a config (useful for testing) This won’t have file watching capabilities.