CLI Arg Parsing library
Structs
- Opts
- The struct for Clap CLI arguments
Functions
- parse_
cli_ args - Parse CLI Arguments turns a Clap Opts struct, seen above Into a library Struct for use within the program The library struct can be found in the config folder.
- read_
and_ parse_ file - When the CLI is called with
-fto open a file this function opens it