pub fn parse_cli_args() -> (String, Config)
Parse CLI Arguments turns a Clap Opts struct, seen above Into a library Struct for use within the program The library struct can be found in the config folder.
This function can panic when it gets both a file and text input at the same time.