The CLI Pretty Printing module contains the functions that print the results
Functions
- countdown_
until_ program_ ends - Every second the timer ticks once If the timer hits our countdown, we exit the program. This function prints the countdown to let the user know the program is still running.
- decoded_
how_ many_ times - The output function is used to print the output of the program.
- failed_
to_ decode - When Ares has failed to decode something, print this message
- human_
checker_ check - Whenever the human checker checks for text, this function is run. The human checker checks to see if API mdoe is runnign inside of it rather than doing it here at the printing level
- panic_
failure_ both_ input_ and_ fail_ provided - The user has provided both textual input and file input
- panic_
failure_ no_ input_ provided - The user has not provided any input.
- program_
exiting_ successful_ decoding - The output function is used to print the output of the program. If the API mode is on, it will not print.
- return_
early_ because_ input_ text_ is_ plaintext - The input given to Ares is already plaintext So we do not need to do anything